@@ -65,9 +65,10 @@
 #endif
 
 #ifdef G_PLATFORM_WIN32
-#  define STRICT			/* Strict typing, please */
+#  define STRICT		/* Strict typing, please */
 #  include <windows.h>
 #  undef STRICT
+#  include <lmcons.h>		/* For UNLEN */
 #  include <ctype.h>
 #endif /* G_PLATFORM_WIN32 */
 
@@ -79,6 +80,10 @@
 #include <langinfo.h>
 #endif
 
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+#include <libintl.h>
+#endif
+
 const guint glib_major_version = GLIB_MAJOR_VERSION;
 const guint glib_minor_version = GLIB_MINOR_VERSION;
 const guint glib_micro_version = GLIB_MICRO_VERSION;
@@ -743,10 +748,12 @@ g_get_any_init (void)
 #endif /* G_OS_WIN32 */
 	}
       
-      if (!g_home_dir)
-	g_home_dir = g_strdup (g_getenv ("HOME"));
-      
 #ifdef G_OS_WIN32
+      /* We check $HOME first for Win32, though it is a last resort for Unix
+       * where we prefer the results of getpwuid().
+       */
+      g_home_dir = g_strdup (g_getenv ("HOME"));
+      
       /* In case HOME is Unix-style (it happens), convert it to
        * Windows style.
        */
@@ -868,8 +875,8 @@ g_get_any_init (void)
       
 #  ifdef G_OS_WIN32
       {
-	guint len = 17;
-	gchar buffer[17];
+	guint len = UNLEN+1;
+	gchar buffer[UNLEN+1];
 	
 	if (GetUserName ((LPTSTR) buffer, (LPDWORD) &len))
 	  {
@@ -878,8 +885,11 @@ g_get_any_init (void)
 	  }
       }
 #  endif /* G_OS_WIN32 */
-      
+
 #endif /* !HAVE_PWD_H */
+
+      if (!g_home_dir)
+	g_home_dir = g_strdup (g_getenv ("HOME"));
       
 #ifdef __EMX__
       /* change '\\' in %HOME% to '/' */
@@ -1084,6 +1094,9 @@ _glib_gettext (const gchar *str)
   if (!_glib_gettext_initialized)
     {
       bindtextdomain(GETTEXT_PACKAGE, GLIB_LOCALE_DIR);
+#    ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+      bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#    endif
       _glib_gettext_initialized = TRUE;
     }
   
