@@ -1,5 +1,5 @@
 /* GObject - GLib Type, Object, Parameter and Signal Library
- * Copyright (C) 1998, 1999, 2000 Tim Janik and Red Hat, Inc.
+ * Copyright (C) 1998-1999, 2000-2001 Tim Janik and Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,6 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/*
+ * MT safe
+ */
+
 #include        <string.h>
 
 #include	"genums.h"
@@ -33,14 +37,14 @@ static void	g_flags_class_init		(GFlagsClass	*class,
 static void	value_flags_enum_init		(GValue		*value);
 static void	value_flags_enum_copy_value	(const GValue	*src_value,
 						 GValue		*dest_value);
-static gchar*	value_flags_enum_collect_value (GValue		*value,
-						guint		 nth_value,
-						GType		*collect_type,
-						GTypeCValue	*collect_value);
+static gchar*	value_flags_enum_collect_value  (GValue		*value,
+						 guint           n_collect_values,
+						 GTypeCValue    *collect_values,
+						 guint           collect_flags);
 static gchar*	value_flags_enum_lcopy_value	(const GValue	*value,
-						 guint		 nth_value,
-						 GType		*collect_type,
-						 GTypeCValue	*collect_value);
+						 guint           n_collect_values,
+						 GTypeCValue    *collect_values,
+						 guint           collect_flags);
 
 
 /* --- functions --- */
@@ -49,13 +53,13 @@ g_enum_types_init (void)	/* sync with gtype.c */
 {
   static gboolean initialized = FALSE;
   static const GTypeValueTable flags_enum_value_table = {
-    value_flags_enum_init,	  /* value_init */
-    NULL,			 	  /* value_free */
+    value_flags_enum_init,	    /* value_init */
+    NULL,			    /* value_free */
     value_flags_enum_copy_value,    /* value_copy */
-    NULL,			  	  /* value_peek_pointer */
-    G_VALUE_COLLECT_INT,	  	  /* collect_type */
+    NULL,			    /* value_peek_pointer */
+    "i",			    /* collect_format */
     value_flags_enum_collect_value, /* collect_value */
-    G_VALUE_COLLECT_POINTER,	  /* lcopy_type */
+    "p",			    /* lcopy_format */
     value_flags_enum_lcopy_value,   /* lcopy_value */
   };
   static GTypeInfo info = {
@@ -81,13 +85,15 @@ g_enum_types_init (void)	/* sync with gtype.c */
   /* G_TYPE_ENUM
    */
   info.class_size = sizeof (GEnumClass);
-  type = g_type_register_fundamental (G_TYPE_ENUM, "GEnum", &info, &finfo, G_TYPE_FLAG_ABSTRACT);
+  type = g_type_register_fundamental (G_TYPE_ENUM, "GEnum", &info, &finfo,
+				      G_TYPE_FLAG_ABSTRACT | G_TYPE_FLAG_VALUE_ABSTRACT);
   g_assert (type == G_TYPE_ENUM);
   
   /* G_TYPE_FLAGS
    */
   info.class_size = sizeof (GFlagsClass);
-  type = g_type_register_fundamental (G_TYPE_FLAGS, "GFlags", &info, &finfo, G_TYPE_FLAG_ABSTRACT);
+  type = g_type_register_fundamental (G_TYPE_FLAGS, "GFlags", &info, &finfo,
+				      G_TYPE_FLAG_ABSTRACT | G_TYPE_FLAG_VALUE_ABSTRACT);
   g_assert (type == G_TYPE_FLAGS);
 }
 
@@ -106,30 +112,28 @@ value_flags_enum_copy_value (const GValue *src_value,
 
 static gchar*
 value_flags_enum_collect_value (GValue      *value,
-				guint	     nth_value,
-				GType	    *collect_type,
-				GTypeCValue *collect_value)
+				guint        n_collect_values,
+				GTypeCValue *collect_values,
+				guint        collect_flags)
 {
-  value->data[0].v_long = collect_value->v_int;
-  
-  *collect_type = 0;
+  value->data[0].v_long = collect_values[0].v_int;
+
   return NULL;
 }
 
 static gchar*
 value_flags_enum_lcopy_value (const GValue *value,
-			      guint	    nth_value,
-			      GType	   *collect_type,
-			      GTypeCValue  *collect_value)
+			      guint         n_collect_values,
+			      GTypeCValue  *collect_values,
+			      guint         collect_flags)
 {
-  gint *int_p = collect_value->v_pointer;
+  gint *int_p = collect_values[0].v_pointer;
   
   if (!int_p)
     return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
   
   *int_p = value->data[0].v_long;
   
-  *collect_type = 0;
   return NULL;
 }
 
@@ -376,7 +380,7 @@ g_flags_get_first_value (GFlagsClass *flags_class,
       GFlagsValue *flags_value;
       
       for (flags_value = flags_class->values; flags_value->value_name; flags_value++)
-	if ((flags_value->value & value) > 0)
+	if ((flags_value->value & value) == flags_value->value)
 	  return flags_value;
     }
   
@@ -387,7 +391,7 @@ void
 g_value_set_enum (GValue *value,
 		  gint    v_enum)
 {
-  g_return_if_fail (G_IS_VALUE_ENUM (value));
+  g_return_if_fail (G_VALUE_HOLDS_ENUM (value));
   
   value->data[0].v_long = v_enum;
 }
@@ -395,7 +399,7 @@ g_value_set_enum (GValue *value,
 gint
 g_value_get_enum (const GValue *value)
 {
-  g_return_val_if_fail (G_IS_VALUE_ENUM (value), 0);
+  g_return_val_if_fail (G_VALUE_HOLDS_ENUM (value), 0);
   
   return value->data[0].v_long;
 }
@@ -404,7 +408,7 @@ void
 g_value_set_flags (GValue *value,
 		   guint   v_flags)
 {
-  g_return_if_fail (G_IS_VALUE_FLAGS (value));
+  g_return_if_fail (G_VALUE_HOLDS_FLAGS (value));
   
   value->data[0].v_ulong = v_flags;
 }
@@ -412,7 +416,7 @@ g_value_set_flags (GValue *value,
 guint
 g_value_get_flags (const GValue *value)
 {
-  g_return_val_if_fail (G_IS_VALUE_FLAGS (value), 0);
+  g_return_val_if_fail (G_VALUE_HOLDS_FLAGS (value), 0);
   
   return value->data[0].v_ulong;
 }
